import{d,eB as g,H as p,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.6830fc2d.js";import{B as _}from"./BaseLayout.950bd7b6.js";import{a as h}from"./asyncComputed.46a733c1.js";import"./router.c745a3c2.js";import"./index.fddb9e1e.js";import{P as z}from"./project.bd61c28b.js";import{O as y}from"./organization.fc8c0ca6.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.0ccb2e11.js";import{S as I}from"./Sidebar.041e12c7.js";import{e as w,J as O,K as C,L as B,M as k,N as L,o as P,O as $,s as E,E as M,F as N,G as S}from"./icons.31e4fa46.js";import"./FormItem.278e4518.js";import"./hasIn.48daad41.js";import"./index.cf4c23b9.js";import"./record.416df660.js";import"./pubsub.6d4f7540.js";import"./logo.084e5d7c.js";import"./Text.b2a17f23.js";import"./Base.e8ab0cc0.js";import"./index.5ed48f82.js";import"./index.ec7fc193.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="832c1a88-9a40-4d8e-83a9-c38c2c865fb9",o._sentryDebugIdIdentifier="sentry-dbid-832c1a88-9a40-4d8e-83a9-c38c2c865fb9")}catch{}})();const oa=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=p(()=>{var e,t,n,l;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(l=a.value)==null?void 0:l.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=p(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:L},{name:"Files",path:"files",icon:P},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:E,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:N,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.4121e422.js.map
