import{N as l}from"./NavbarControls.34ef81d3.js";import{d as _,eA as b,eB as y,H as g,a as v,b as c,ev as h,f as e,w as s,u as a,e as k,a$ as w,ar as S,c as x,eS as q,v as A}from"./outputWidgets.6830fc2d.js";import{A as B}from"./Text.b2a17f23.js";import{T as C,A as o}from"./TabPane.e9b52363.js";import{c as I}from"./index.5ed48f82.js";import"./index.60a3b943.js";import"./pubsub.6d4f7540.js";import"./asyncComputed.46a733c1.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.32a11dff.js";import"./ant-design.f8e1bed1.js";import"./index.e51935e8.js";import"./Modal.e109cdd2.js";import"./Base.e8ab0cc0.js";import"./Link.9fd1fe6c.js";import"./index.79e1d321.js";import"./workspaces.a2016f40.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";import"./record.416df660.js";import"./popupNotifcation.339ee2ee.js";import"./CircularLoading.e5a979d6.js";import"./icons.31e4fa46.js";import"./index.a26dbe33.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.6b319732.js";import"./Paragraph.c22304c7.js";import"./hasIn.48daad41.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="67e5efef-4117-470c-9066-ac1ff93d3a67",r._sentryDebugIdIdentifier="sentry-dbid-67e5efef-4117-470c-9066-ac1ff93d3a67")}catch{}})();const T={class:"content"},D=_({__name:"Settings",setup(r){const t=b(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(B),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:f})=>[(c(),x(q(f)))]),_:1})])],64)}}});const oe=A(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.4360255e.js.map
