import{d as b,eA as w,eB as k,r as x,H as y,b as n,c as d,w as t,ev as h,eC as I,u as l,bu as C,ez as f,f as s,I as B,ar as N,eD as D,a$ as S,bw as V,v as A,eE as E,eF as L,e as g,a as p,ex as T}from"./outputWidgets.6830fc2d.js";import{h as $,s as H}from"./icons.31e4fa46.js";import{_ as z}from"./logo.084e5d7c.js";import{B as F}from"./BaseLayout.950bd7b6.js";import{N as M}from"./NavbarControls.34ef81d3.js";import{c as R}from"./index.5ed48f82.js";import"./index.60a3b943.js";import"./pubsub.6d4f7540.js";import"./asyncComputed.46a733c1.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.32a11dff.js";import"./ant-design.f8e1bed1.js";import"./index.e51935e8.js";import"./Modal.e109cdd2.js";import"./Base.e8ab0cc0.js";import"./Link.9fd1fe6c.js";import"./index.79e1d321.js";import"./workspaces.a2016f40.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";import"./record.416df660.js";import"./popupNotifcation.339ee2ee.js";import"./CircularLoading.e5a979d6.js";import"./index.a26dbe33.js";import"./Text.b2a17f23.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.6b319732.js";import"./Paragraph.c22304c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9b7e3bb9-f4ef-4d45-b859-f5856d6d9d85",e._sentryDebugIdIdentifier="sentry-dbid-9b7e3bb9-f4ef-4d45-b859-f5856d6d9d85")}catch{}})();const W=b({__name:"Sidebar",setup(e){var m;const o=w(),c=k(),r=x((m=c.name)!=null?m:"forms"),u=y(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:H,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),d(l(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),h(S,null,I(u.value,a=>(n(),d(l(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const P={},v=e=>(E("data-v-81cd596e"),e=e(),L(),e),j={class:"logo"},q=v(()=>g("img",{src:z,alt:"Abstra cloud logo"},null,-1)),G=v(()=>g("span",null," Abstra ",-1)),J=[q,G];function K(e,o){return n(),h("div",j,J)}const O=A(P,[["render",K],["__scopeId","data-v-81cd596e"]]),ye=b({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),d(F,null,{navbar:t(()=>[s(l(R),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(M,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(W,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{ye as default};
//# sourceMappingURL=Workspace.d05aac4a.js.map
