import{g as i}from"./api.982dc47e.js";import{P as m}from"./Passwordless.1ac165b7.js";import{a as p}from"./asyncComputed.46a733c1.js";import{W as u}from"./WidgetsFrame.33243032.js";import{d as f,eA as l,eB as _,b as d,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.6830fc2d.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";import"./index.60a3b943.js";import"./pubsub.6d4f7540.js";import"./icons.31e4fa46.js";import"./CircularLoading.e5a979d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="25abc011-80e3-48ce-a7de-398fdd90c487",e._sentryDebugIdIdentifier="sentry-dbid-25abc011-80e3-48ce-a7de-398fdd90c487")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=p(i),c=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[g("div",x,[s(o)?(d(),b(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.af243d49.js.map
