import{ac as p,V as t,Q as d,f as c}from"./outputWidgets.6830fc2d.js";import{B as f,b as l}from"./Base.e8ab0cc0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="f238e3dd-2b14-44c2-8d56-3ac407b70256",e._sentryDebugIdIdentifier="sentry-dbid-f238e3dd-2b14-44c2-8d56-3ac407b70256")}catch{}})();const b=()=>t(t({},d(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:r}=s;const{ellipsis:n}=e;p();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?d(n,["expandable","rows"]):n,component:"span"}),r);return c(f,i,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.b2a17f23.js.map
