import"./outputWidgets.6830fc2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="8b0a5a48-6032-4f2c-ac2f-42b99ba632bc",e._sentryDebugIdIdentifier="sentry-dbid-8b0a5a48-6032-4f2c-ac2f-42b99ba632bc")}catch{}})();function i(e){return e.charAt(0).toUpperCase()+e.slice(1)}function l(e,a,n=!1,o=!0){const r=(o?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=n?r:r.replace(/_+/g,"_");return a?c:c.replace(/_$/,"")}function u(e){var r;const n=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),o=/[a-z0-9]+/g,t=n.match(o);return(r=t==null?void 0:t.join("-"))!=null?r:""}function f(e){try{return JSON.parse(e),!0}catch{return!1}}export{u as a,i as c,l as n,f as v};
//# sourceMappingURL=string.81ef85b7.js.map
