import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.21cae368.js";import{K as d,P as b,L as l}from"./repository.e9cb7dee.js";import{d as u,b as f,ev as c,f as p,u as r}from"./outputWidgets.6830fc2d.js";import{u as g}from"./index.60a3b943.js";import{a as y}from"./asyncComputed.46a733c1.js";import{g as _}from"./api.982dc47e.js";import"./Text.b2a17f23.js";import"./Base.e8ab0cc0.js";import"./index.7bf97bdd.js";import"./Link.9fd1fe6c.js";import"./Paragraph.c22304c7.js";import"./Title.10b04a9c.js";import"./index.5ed48f82.js";import"./ant-design.f8e1bed1.js";import"./index.e51935e8.js";import"./Modal.e109cdd2.js";import"./metadata.7c5b6440.js";import"./icons.31e4fa46.js";import"./index.a26dbe33.js";import"./index.ec7fc193.js";import"./index.6a8055e7.js";import"./index.b0a80c9e.js";import"./index.d467c68d.js";import"./Card.03412a32.js";import"./TabPane.e9b52363.js";import"./hasIn.48daad41.js";import"./CollapsePanel.a4052cc9.js";import"./Form.a8618886.js";import"./FormItem.278e4518.js";import"./Timeline.cfdef03c.js";import"./index.1562909b.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.df963128.js";import"./index.cf4c23b9.js";import"./scripts.48cf1ca3.js";import"./record.416df660.js";import"./pubsub.6d4f7540.js";import"./workspaces.a2016f40.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";import"./ExpandOutlined.fba0d71e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="74047e94-db40-4d13-93eb-94deb4048775",o._sentryDebugIdIdentifier="sentry-dbid-74047e94-db40-4d13-93eb-94deb4048775")}catch{}})();const po=u({__name:"Kanban",setup(o){const t=new b(g),n=new l("kanban"),{result:e}=y(_);return(k,w)=>{var a,i,m;return f(),c("div",null,[p(s,{"brand-name":((a=r(e))==null?void 0:a.brandName)||((i=r(e))==null?void 0:i.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(n)},null,8,["kanban-repository","storage"])])}}});export{po as default};
//# sourceMappingURL=Kanban.95e646c6.js.map
