import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.21cae368.js";import{g as p}from"./api.982dc47e.js";import{a as _}from"./asyncComputed.46a733c1.js";import{W as b}from"./WidgetsFrame.33243032.js";import{d as y,eB as g,b as n,ev as h,e as a,u as t,c as m,w as v,ex as l,eD as u,v as w}from"./outputWidgets.6830fc2d.js";import"./index.60a3b943.js";import"./pubsub.6d4f7540.js";import"./Text.b2a17f23.js";import"./Base.e8ab0cc0.js";import"./index.7bf97bdd.js";import"./Link.9fd1fe6c.js";import"./Paragraph.c22304c7.js";import"./Title.10b04a9c.js";import"./index.5ed48f82.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="4d3bdef7-c62b-40e8-9e1c-bd55d2487fb7",o._sentryDebugIdIdentifier="sentry-dbid-4d3bdef7-c62b-40e8-9e1c-bd55d2487fb7")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=y({__name:"Error",setup(o){const r=g(),{result:e}=_(p),c=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),m(b,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var i,d;return[t(e)?(n(),m(f,{key:0,"brand-name":((i=t(e))==null?void 0:i.brandName)||((d=t(e))==null?void 0:d.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(c().status),1),a("p",null,u(c().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.d26e2def.js.map
