import{r as a,w as n}from"./runnerData.d09750b2.js";import"./outputWidgets.6830fc2d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="64601a26-6bc5-4e3f-9835-42c35e127cc3",t._sentryDebugIdIdentifier="sentry-dbid-64601a26-6bc5-4e3f-9835-42c35e127cc3")}catch{}})();async function c(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:r}=await e.json();return{form:r&&a(r)}}async function f(){const t=await fetch("/_workspace");if(t.status!=200)return n({});const e=await t.json();return n(e)}export{c as a,f as g};
//# sourceMappingURL=api.982dc47e.js.map
