import{v as a,a as r,b as i,c,j as d,T as p,k as _,P as u,C as f,M as b,s as l,l as s,m as g,n as m,p as y,q as v}from"./outputWidgets.6830fc2d.js";import{s as w,a as o}from"./index.60a3b943.js";import"./pubsub.6d4f7540.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="90e8fe09-698d-4edc-b22b-eea4aaf442bc",e._sentryDebugIdIdentifier="sentry-dbid-90e8fe09-698d-4edc-b22b-eea4aaf442bc")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=a(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>g(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",b),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.fd699dd2.js.map
