import{eV as t,eW as d}from"./outputWidgets.6830fc2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="26819474-9793-437e-b9a6-d7205d5b68d8",e._sentryDebugIdIdentifier="sentry-dbid-26819474-9793-437e-b9a6-d7205d5b68d8")}catch{}})();function s(e,n){return t(1,arguments),d(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.6a8055e7.js.map
