import{K as n,E as a,L as p}from"./repository.e9cb7dee.js";import{d as s,b as m,c,u as e}from"./outputWidgets.6830fc2d.js";import{l as d}from"./index.60a3b943.js";import"./ant-design.f8e1bed1.js";import"./index.e51935e8.js";import"./Modal.e109cdd2.js";import"./asyncComputed.46a733c1.js";import"./metadata.7c5b6440.js";import"./icons.31e4fa46.js";import"./index.a26dbe33.js";import"./index.ec7fc193.js";import"./index.6a8055e7.js";import"./Paragraph.c22304c7.js";import"./Base.e8ab0cc0.js";import"./index.7bf97bdd.js";import"./Link.9fd1fe6c.js";import"./Text.b2a17f23.js";import"./Title.10b04a9c.js";import"./index.b0a80c9e.js";import"./index.d467c68d.js";import"./Card.03412a32.js";import"./TabPane.e9b52363.js";import"./hasIn.48daad41.js";import"./CollapsePanel.a4052cc9.js";import"./Form.a8618886.js";import"./FormItem.278e4518.js";import"./Timeline.cfdef03c.js";import"./index.1562909b.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.df963128.js";import"./index.cf4c23b9.js";import"./scripts.48cf1ca3.js";import"./record.416df660.js";import"./pubsub.6d4f7540.js";import"./workspaces.a2016f40.js";import"./runnerData.d09750b2.js";import"./url.1f48e231.js";import"./ExpandOutlined.fba0d71e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="a0fa79e3-f281-4d01-ad76-b864cdb47c87",t._sentryDebugIdIdentifier="sentry-dbid-a0fa79e3-f281-4d01-ad76-b864cdb47c87")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const $=s({__name:"WorkflowKanban",setup(t){const o=new a,r=new f,i=new p("kanban");return(u,b)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{$ as default};
//# sourceMappingURL=WorkflowKanban.f2553f40.js.map
