import{C as t,E as i,K as b,a as d,M as f,c as l,P as y,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.ab23e6f0.js";import"./outputWidgets.6830fc2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3b7fabb9-8236-4427-a413-5035a689bb04",e._sentryDebugIdIdentifier="sentry-dbid-3b7fabb9-8236-4427-a413-5035a689bb04")}catch{}})();export{t as CancellationTokenSource,i as Emitter,b as KeyCode,d as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.d29cb4a9.js.map
