import{v as t,b as s,ev as d}from"./outputWidgets.6830fc2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="dd3f327c-45f6-4675-90a9-451cf915d0ac",e._sentryDebugIdIdentifier="sentry-dbid-dd3f327c-45f6-4675-90a9-451cf915d0ac")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.33853ad4.js.map
