import"./outputWidgets.6830fc2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="eadb8d14-b643-4165-b723-1c81a2f40f31",e._sentryDebugIdIdentifier="sentry-dbid-eadb8d14-b643-4165-b723-1c81a2f40f31")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.1f48e231.js.map
