import{a as e,B as s}from"./Base.e8ab0cc0.js";import{A as t}from"./Link.9fd1fe6c.js";import{A as o}from"./Paragraph.c22304c7.js";import{A as r}from"./Text.b2a17f23.js";import{A as i}from"./Title.10b04a9c.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="2cb73bfd-9ab1-4f31-b948-7aa0398d62a3",a._sentryDebugIdIdentifier="sentry-dbid-2cb73bfd-9ab1-4f31-b948-7aa0398d62a3")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=t;e.Base=s;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,r),a.component(e.Title.displayName,i),a.component(e.Paragraph.displayName,o),a.component(e.Link.displayName,t),a};
//# sourceMappingURL=index.7bf97bdd.js.map
